dataset_type = 'FundusDataset'
multi_dataset_type = 'ConcatEvalDataset'
numerWorker = 8
batch = 32
data_root_path = 'data'

train_pipeline = [
    # load image
    dict(type='LoadImageFromFile'),
    dict(type='ResizeEdge', scale=512, edge='short'),
    dict(type='RandomCrop', crop_size=(640, 512)),
    dict(type='SLORandomPad', size=(640, 512)),
    dict(type='FundRandomRotate', prob=0.5, degree=30),
    dict(type='RandomFlip', prob=0.5, direction='horizontal'),
    dict(type='RandomFlip', prob=0.5, direction='vertical'),
    dict(type='Brightness', magnitude_range=(0, 0.9)),
    dict(type='PackMultiTaskInputs', multi_task_fields=('gt_label',)),
]

val_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(type='ResizeEdge', scale=512, edge='short'),
    dict(type='CenterCrop', crop_size=(640, 512)),
    dict(type='CenterPad', size=(640, 512), pad_val=0),
    dict(type='PackMultiTaskInputs', multi_task_fields=('gt_label',)),
]
test_pipeline = [
    # load image
    dict(type='LoadImageFromFile'),
    dict(type='ResizeEdge', scale=512, edge='short'),
    dict(type='CenterCrop', crop_size=(640, 512)),
    dict(type='CenterPad', size=(640, 512), pad_val=0),
    dict(type='PackMultiTaskInputs', multi_task_fields=('gt_label',)),
]

train_dataloader = dict(
    batch_size=batch,
    num_workers=numerWorker,
    dataset=dict(
        type=dataset_type,
        data_root=data_root_path,
        ann_file='fundus_annotations/train.json',
        pipeline=train_pipeline),
    sampler=dict(type='ModifiedSampler', patientshuffle=True),
)

val_dataloader = dict(
    batch_size=batch,
    num_workers=numerWorker,
    dataset=dict(
        type=multi_dataset_type,
        datasets=[
            dict(
                type=dataset_type,
                data_root=data_root_path,
                ann_file='fundus_annotations/train.json',
                pipeline=train_pipeline
            ),
            dict(
                type=dataset_type,
                data_root=data_root_path,
                ann_file='fundus_annotations/val.json',
                pipeline=val_pipeline
            ),
            dict(
                type=dataset_type,
                data_root=data_root_path,
                ann_file='fundus_annotations/test.json',
                pipeline=test_pipeline
            )
        ]
    ),
    sampler=dict(type='DefaultSampler', shuffle=False),
)

val_evaluator = dict(
    type='FundusMultiDatasetsEvaluator',
    dataset_prefixes=['train', 'val', 'test'],

    metrics=dict(
        type='FundusMultiTasksMetric',
        task_metrics={
            'T0': [
                dict(type='SingleLabelMetric_V2', average=None),
                dict(type='Kappa_V2'),
            ],
            'T1': [
                dict(type='SingleLabelMetric_V2', average=None),
                dict(type='Kappa_V2'),
            ],
            'T2': [
                dict(type='SingleLabelMetric_V2', average=None),
                dict(type='Kappa_V2'),
            ],
        }
    )
)

test_dataloader = dict(
    batch_size=batch,
    num_workers=numerWorker,
    dataset=dict(
        type=dataset_type,
        data_root=data_root_path,
        ann_file='fundus_annotations/test.json',
        pipeline=test_pipeline),
    sampler=dict(type='DefaultSampler', shuffle=False),
)
test_evaluator = dict(
    type='FundusMultiTasksMetric',
    task_metrics={
        'T0': [
            dict(type='SingleLabelMetric_V2', average=None),
            dict(type='Kappa_V2'),
        ],
        'T1': [
            dict(type='SingleLabelMetric_V2', average=None),
            dict(type='Kappa_V2'),
        ],
        'T2': [
            dict(type='SingleLabelMetric_V2', average=None),
            dict(type='Kappa_V2'),
        ],
    }
)
