from collections import defaultdict
import os
import pickle
from sklearn.metrics import *

def calculate_accuracy(pred_labels, gt_labels):
    correct = sum(pred == gt for pred, gt in zip(pred_labels, gt_labels))
    total = len(pred_labels)
    accuracy = correct / total
    return accuracy

def calculate_correct_union_consistency(info_labels, pred_labels, gt_label):
    eye_counts = defaultdict(int)
    eye_unions = defaultdict(set)
    eye_gt = defaultdict(set)
    multi_scans_eye_counts = defaultdict(int)

    for info, pred, gt in zip(info_labels, pred_labels, gt_label):
        eye_counts[info] += 1
        eye_unions[info].add(pred)
        eye_gt[info].add(gt)

    for eye in eye_counts:
        if eye_counts[eye] > 1:
            multi_scans_eye_counts[eye]=eye_counts[eye]

    total_consistency = 0

    for eye in eye_unions:
        union = eye_unions[eye]
        gt = eye_gt[eye]
        scans = eye_counts[eye]
        consistency = 1 if len(union) == 1 and union == gt and scans > 1 else 0
        total_consistency += consistency

    consistency = total_consistency / len(multi_scans_eye_counts)

    return consistency


def calculate_union_consistency(info_labels, pred_labels):
    eye_counts = defaultdict(int)
    eye_unions = defaultdict(set)
    multi_scans_eye_counts = defaultdict(int)

    for info, pred in zip(info_labels, pred_labels):
        eye_counts[info] += 1
        eye_unions[info].add(pred)

    for eye in eye_counts:
        if eye_counts[eye] > 1:
            multi_scans_eye_counts[eye]=eye_counts[eye]

    total_consistency = 0

    for eye in eye_unions:
        union = eye_unions[eye]
        scans = eye_counts[eye]
        consistency = 1 if len(union) == 1 and scans > 1 else 0
        total_consistency += consistency

    consistency = total_consistency / len(multi_scans_eye_counts)

    return consistency


if __name__ == '__main__':
    file = "..\\pred.pkl"

    with open(file, 'rb') as f:
        a = pickle.load(f)
    ME_pred_list = []
    DR_pred_list = []
    GA_pred_list = []
    ME_gt_list = []
    DR_gt_list = []
    GA_gt_list = []
    ME_info_list = []
    DR_info_list = []
    GA_info_list = []
    for i in a:
        ME_pred_label = i["T0"]['pred_label']['label'].item()
        ME_gt_label = i["T0"]['gt_label']['label'].item()
        path = i["T0"]["img_path"]
        index = path.rfind('/')
        info = path[:index]
        if ME_gt_label == -100:
            continue
        ME_pred_list.append(ME_pred_label)
        ME_gt_list.append(ME_gt_label)
        ME_info_list.append(info)

    for i in a:
        DR_pred_label = i["T1"]['pred_label']['label'].item()
        DR_gt_label = i["T1"]['gt_label']['label'].item()
        path = i["T1"]["img_path"]
        index = path.rfind('/')
        info = path[:index]
        if DR_gt_label == -100:
            continue
        DR_pred_list.append(DR_pred_label)
        DR_gt_list.append(DR_gt_label)
        DR_info_list.append(info)

    for i in a:
        GA_pred_label = i["T2"]['pred_label']['label'].item()
        GA_gt_label = i["T2"]['gt_label']['label'].item()
        path = i["T2"]["img_path"]
        index = path.rfind('/')
        info = path[:index]
        if GA_gt_label == -100:
            continue
        GA_pred_list.append(GA_pred_label)
        GA_gt_list.append(GA_gt_label)
        GA_info_list.append(info)
    print("file from: "+file)

    ME_kappa = cohen_kappa_score(ME_gt_list, ME_pred_list, weights='quadratic')
    # print("ME_Kappa: ", "{:.2f}".format(ME_kappa * 100))
    DR_kappa = cohen_kappa_score(DR_gt_list, DR_pred_list, weights='quadratic')
    # print("DR_Kappa: ", "{:.2f}".format(DR_kappa * 100))
    GA_kappa = cohen_kappa_score(GA_gt_list, GA_pred_list, weights='quadratic')
    # print("GA_kappa: ", "{:.2f}".format(GA_kappa * 100))
    class_wise_kappa = (ME_kappa+DR_kappa+GA_kappa)/3

    ME_acc = calculate_accuracy(ME_pred_list, ME_gt_list)
    DR_acc = calculate_accuracy(DR_pred_list, DR_gt_list)
    GA_acc = calculate_accuracy(GA_pred_list, GA_gt_list)
    macro_acc = (ME_acc+DR_acc+GA_acc)/3

    ME_con = calculate_union_consistency(ME_info_list, ME_pred_list)
    DR_con = calculate_union_consistency(DR_info_list, DR_pred_list)
    GA_con = calculate_union_consistency(GA_info_list, GA_pred_list)
    macro_con = (ME_con+DR_con+GA_con)/3

    ME_acccon = calculate_correct_union_consistency(ME_info_list, ME_pred_list, ME_gt_list)
    DR_acccon = calculate_correct_union_consistency(DR_info_list, DR_pred_list, DR_gt_list)
    GA_acccon = calculate_correct_union_consistency(GA_info_list, GA_pred_list, GA_gt_list)
    macro_acccon = (ME_acccon+DR_acccon+GA_acccon)/3

    print("ME ****************************************************************************")
    print("ME_Kappa: ", "{:.2f}".format(ME_kappa * 100))
    print("ME_acc: " + str(format(ME_acc* 100, '.2f')))
    print("ME_con: "+str(format(ME_con* 100, '.2f')))
    print("ME_acccon: "+str(format(ME_acccon* 100, '.2f')))

    print("DR ****************************************************************************")
    print("DR_Kappa: ", "{:.2f}".format(DR_kappa * 100))
    print("DR_acc: " + str(format(DR_acc* 100, '.2f')))
    print("DR_con: "+str(format(DR_con* 100, '.2f')))
    print("DR_acccon: "+str(format(DR_acccon* 100, '.2f')))

    print("GA ****************************************************************************")
    print("GA_kappa: ", "{:.2f}".format(GA_kappa * 100))
    print("GA_acc: " + str(format(GA_acc* 100, '.2f')))
    print("GA_con: "+str(format(GA_con* 100, '.2f')))
    print("GA_acccon: "+str(format(GA_acccon* 100, '.2f')))