dataset_type = 'FundusDataset'
multi_dataset_type = 'ConcatEvalDataset'
numerWorker = 8
batch = 32
data_root_path = 'data'
train_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(type='ResizeEdge', scale=512, edge='short'),
    dict(type='RandomCrop', crop_size=(640, 512)),
    dict(type='SLORandomPad', size=(640, 512)),
    dict(type='FundRandomRotate', prob=0.5, degree=30),
    dict(type='RandomFlip', prob=0.5, direction='horizontal'),
    dict(type='RandomFlip', prob=0.5, direction='vertical'),
    dict(type='Brightness', magnitude_range=(0, 0.9)),
    dict(type='PackMultiTaskInputs', multi_task_fields=('gt_label', ))
]
val_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(type='ResizeEdge', scale=512, edge='short'),
    dict(type='CenterCrop', crop_size=(640, 512)),
    dict(type='CenterPad', size=(640, 512), pad_val=0),
    dict(type='PackMultiTaskInputs', multi_task_fields=('gt_label', ))
]
test_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(type='ResizeEdge', scale=512, edge='short'),
    dict(type='CenterCrop', crop_size=(640, 512)),
    dict(type='CenterPad', size=(640, 512), pad_val=0),
    dict(type='PackMultiTaskInputs', multi_task_fields=('gt_label', ))
]
train_dataloader = dict(
    batch_size=32,
    num_workers=8,
    dataset=dict(
        type='FundusDataset',
        data_root='data',
        ann_file='fundus_annotations/train.json',
        pipeline=[
            dict(type='LoadImageFromFile'),
            dict(type='ResizeEdge', scale=512, edge='short'),
            dict(type='RandomCrop', crop_size=(640, 512)),
            dict(type='SLORandomPad', size=(640, 512)),
            dict(type='FundRandomRotate', prob=0.5, degree=30),
            dict(type='RandomFlip', prob=0.5, direction='horizontal'),
            dict(type='RandomFlip', prob=0.5, direction='vertical'),
            dict(type='Brightness', magnitude_range=(0, 0.9)),
            dict(type='PackMultiTaskInputs', multi_task_fields=('gt_label', ))
        ]),
    sampler=dict(type='ModifiedSampler', patientshuffle=True))
val_dataloader = dict(
    batch_size=32,
    num_workers=8,
    dataset=dict(
        type='ConcatEvalDataset',
        datasets=[
            dict(
                type='FundusDataset',
                data_root='data',
                ann_file='fundus_annotations/train.json',
                pipeline=[
                    dict(type='LoadImageFromFile'),
                    dict(type='ResizeEdge', scale=512, edge='short'),
                    dict(type='RandomCrop', crop_size=(640, 512)),
                    dict(type='SLORandomPad', size=(640, 512)),
                    dict(type='FundRandomRotate', prob=0.5, degree=30),
                    dict(type='RandomFlip', prob=0.5, direction='horizontal'),
                    dict(type='RandomFlip', prob=0.5, direction='vertical'),
                    dict(type='Brightness', magnitude_range=(0, 0.9)),
                    dict(
                        type='PackMultiTaskInputs',
                        multi_task_fields=('gt_label', ))
                ]),
            dict(
                type='FundusDataset',
                data_root='data',
                ann_file='fundus_annotations/val.json',
                pipeline=[
                    dict(type='LoadImageFromFile'),
                    dict(type='ResizeEdge', scale=512, edge='short'),
                    dict(type='CenterCrop', crop_size=(640, 512)),
                    dict(type='CenterPad', size=(640, 512), pad_val=0),
                    dict(
                        type='PackMultiTaskInputs',
                        multi_task_fields=('gt_label', ))
                ]),
            dict(
                type='FundusDataset',
                data_root='data',
                ann_file='fundus_annotations/test.json',
                pipeline=[
                    dict(type='LoadImageFromFile'),
                    dict(type='ResizeEdge', scale=512, edge='short'),
                    dict(type='CenterCrop', crop_size=(640, 512)),
                    dict(type='CenterPad', size=(640, 512), pad_val=0),
                    dict(
                        type='PackMultiTaskInputs',
                        multi_task_fields=('gt_label', ))
                ])
        ]),
    sampler=dict(type='DefaultSampler', shuffle=False))
val_evaluator = dict(
    type='FundusMultiDatasetsEvaluator',
    dataset_prefixes=['train', 'val', 'test'],
    metrics=dict(
        type='FundusMultiTasksMetric',
        task_metrics=dict(
            T0=[
                dict(type='SingleLabelMetric_V2', average=None),
                dict(type='Kappa_V2')
            ],
            T1=[
                dict(type='SingleLabelMetric_V2', average=None),
                dict(type='Kappa_V2')
            ],
            T2=[
                dict(type='SingleLabelMetric_V2', average=None),
                dict(type='Kappa_V2')
            ])))
test_dataloader = dict(
    pin_memory=True,
    collate_fn=dict(type='default_collate'),
    batch_size=32,
    num_workers=8,
    dataset=dict(
        type='FundusDataset',
        data_root='data',
        ann_file='fundus_annotations/test.json',
        pipeline=[
            dict(type='LoadImageFromFile'),
            dict(type='ResizeEdge', scale=512, edge='short'),
            dict(type='CenterCrop', crop_size=(640, 512)),
            dict(type='CenterPad', size=(640, 512), pad_val=0),
            dict(type='PackMultiTaskInputs', multi_task_fields=('gt_label', ))
        ]),
    sampler=dict(type='DefaultSampler', shuffle=False))
test_evaluator = dict(
    type='FundusMultiTasksMetric',
    task_metrics=dict(
        T0=[
            dict(type='SingleLabelMetric_V2', average=None),
            dict(type='Kappa_V2')
        ],
        T1=[
            dict(type='SingleLabelMetric_V2', average=None),
            dict(type='Kappa_V2')
        ],
        T2=[
            dict(type='SingleLabelMetric_V2', average=None),
            dict(type='Kappa_V2')
        ]))
lr = 5e-05
optim_wrapper = dict(
    optimizer=dict(
        type='AdamW',
        lr=5e-05,
        weight_decay=0.05,
        eps=1e-08,
        betas=(0.9, 0.999)),
    paramwise_cfg=dict(
        norm_decay_mult=0.0,
        bias_decay_mult=0.0,
        flat_decay_mult=0.0,
        custom_keys=dict({
            '.absolute_pos_embed': dict(decay_mult=0.0),
            '.relative_position_bias_table': dict(decay_mult=0.0)
        })))
param_scheduler = [
    dict(
        type='LinearLR',
        start_factor=0.001,
        by_epoch=True,
        end=20,
        convert_to_iter_based=True),
    dict(type='CosineAnnealingLR', eta_min=5e-06, by_epoch=True, begin=20)
]
train_cfg = dict(by_epoch=True, max_epochs=150, val_interval=10)
val_cfg = dict()
test_cfg = dict()
auto_scale_lr = dict(base_batch_size=256)
default_scope = 'mmcls'
default_hooks = dict(
    timer=dict(type='IterTimerHook'),
    logger=dict(type='LoggerHook', interval=80),
    param_scheduler=dict(type='ParamSchedulerHook'),
    checkpoint=dict(type='CheckpointHook', interval=150),
    sampler_seed=dict(type='DistSamplerSeedHook'),
    visualization=dict(type='VisualizationHook', enable=True))
env_cfg = dict(
    cudnn_benchmark=False,
    mp_cfg=dict(mp_start_method='fork', opencv_num_threads=0),
    dist_cfg=dict(backend='nccl'))
vis_backends = [
    dict(type='LocalVisBackend'),
    dict(type='TensorboardVisBackend')
]
visualizer = dict(
    type='ClsVisualizer',
    vis_backends=[
        dict(type='LocalVisBackend'),
        dict(type='TensorboardVisBackend')
    ])
log_level = 'INFO'
load_from = 'work_dirs/trustdetector_SLO_multi_labels/MICCAI_weights/20240226_124020_epoch_150.pth'
resume = False
randomness = dict(seed=None, deterministic=False)
model = dict(
    type='TrustDetection',
    backbone=dict(
        type='ConvNeXt',
        arch='tiny',
        drop_path_rate=0.2,
        init_cfg=dict(
            type='Pretrained',
            prefix='backbone',
            checkpoint=
            'https://download.openmmlab.com/mmclassification/v0/convnext/convnext-tiny_in21k-pre_3rdparty_in1k-384px_20221219-c1182362.pth'
        )),
    contrastive_loss_1=dict(
        type='EyeConLoss',
        embeddims=128,
        temperature=0.07,
        labeltype='info',
        lossweight_alpha=0.2),
    contrastive_loss_2=dict(
        type='RankLoss', embeddims=128, temperature=0.07, lossweight_beta=0.1),
    head=dict(
        type='MultiTaskHead',
        task_heads=dict(
            T0=dict(
                type='ModifiedLinearClsHead',
                p=0.2,
                num_classes=2,
                loss=dict(
                    type='CrossEntropyLoss',
                    loss_weight=1.0,
                    class_weight=[0.0419, 0.9581])),
            T1=dict(
                type='ModifiedLinearClsHead',
                p=0.2,
                num_classes=2,
                loss=dict(
                    type='CrossEntropyLoss',
                    loss_weight=1.0,
                    class_weight=[0.0978, 0.9022])),
            T2=dict(
                type='ModifiedLinearClsHead',
                p=0.2,
                num_classes=3,
                loss=dict(
                    type='CrossEntropyLoss',
                    loss_weight=1.0,
                    class_weight=[0.0382, 0.4865, 0.4753]))),
        in_channels=768))
launcher = 'pytorch'
work_dir = './work_dirs/trustdetector_SLO_multi_labels'
